<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * HTML HEAD TAG CONTENTS                                                                      * -->
	<!-- *********************************************************************************************** -->


	<!-- HTML header
	   -
	   - This template generates the <head> section of the HTML page.
	  -->
	<xsl:template name="html-header">
		<!-- Site + page title -->
		<title>
			<xsl:call-template name="page-title-template">
				<xsl:with-param name="site-title" select="$c-block/ws:title" />
				<xsl:with-param name="page-title">
					<xsl:call-template name="get-page-title">
						<xsl:with-param name="id" select="$page" />
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
		</title>

		<!-- Content type -->
		<meta http-equiv="Content-Type" content="application/xhtml+xml;charset=utf-8" />

		<!-- Author -->
		<xsl:if test="$page-author">
			<meta name="author">
				<xsl:attribute name="content"><xsl:value-of select="$page-author" /></xsl:attribute>
			</meta>
		</xsl:if>

		<!-- Generate other meta tags -->
		<xsl:call-template name="other-meta-tags" />

		<!-- Load stylesheets and scripts -->
		<xsl:call-template name="load-all-css" />
		<xsl:call-template name="load-all-scripts" />
	</xsl:template>


	<!-- HTML meta tags generator
	   -
	   - This template generates the page's various meta tags from the configuration;
	   - it uses language- and page-specific values if they exist, then language-independant
	   - but page-specific values and finally site-wise values.
	  -->
	<xsl:template name="other-meta-tags">
		<!-- Site-wise meta tags -->
		<xsl:for-each select="$d/ws:meta">
			<xsl:variable name="m-name" select="@name" />
			<xsl:if test="not( $page-meta/ws:meta[@name = $m-name] or $page-data/ws:meta[@name = $m-name] )">
				<meta>
					<xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
					<xsl:attribute name="content"><xsl:value-of select="@content" /></xsl:attribute>
				</meta>
			</xsl:if>
		</xsl:for-each>

		<!-- Language-independant, page-specific meta tags -->
		<xsl:for-each select="$page-meta/ws:meta">
			<xsl:variable name="m-name" select="@name" />
			<xsl:if test="not( $page-data/ws:meta[@name = $m-name] )">
				<meta>
					<xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
					<xsl:attribute name="content"><xsl:value-of select="@content" /></xsl:attribute>
				</meta>
			</xsl:if>
		</xsl:for-each>

		<!-- Language- and page-specific meta tags -->
		<xsl:for-each select="$page-data/ws:meta">
			<meta>
				<xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
				<xsl:attribute name="content"><xsl:value-of select="@content" /></xsl:attribute>
			</meta>
		</xsl:for-each>
	</xsl:template>


	<!-- Load user stylesheets
	   -
	   - This template loads both site-wise stylesheets and page-specific stylesheets.
	  -->
	<xsl:template name="load-all-css">
		<!-- Site stylesheets -->
		<xsl:for-each select="$d/ws:css">
			<xsl:call-template name="include-css"><xsl:with-param name="file" select="." /></xsl:call-template>
		</xsl:for-each>
		<!-- Language-specific stylesheets -->
		<xsl:for-each select="$c-block/ws:css">
			<xsl:call-template name="include-css"><xsl:with-param name="file" select="." /></xsl:call-template>
		</xsl:for-each>
		<!-- Page stylesheets -->
		<xsl:for-each select="$page-meta/ws:css">
			<xsl:call-template name="include-css"><xsl:with-param name="file" select="." /></xsl:call-template>
		</xsl:for-each>
		<!-- Language-specific page stylesheets -->
		<xsl:for-each select="$page-data/ws:css">
			<xsl:call-template name="include-css"><xsl:with-param name="file" select="." /></xsl:call-template>
		</xsl:for-each>
	</xsl:template>


	<!-- JavaScript loader
	   -
	   - This template loads all required JavaScript files.
	  -->
	<xsl:template name="load-all-scripts">
		<xsl:for-each select="$d/ws:script">
			<xsl:call-template name="include-javascript"><xsl:with-param name="file" select="."/></xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="$c-block/ws:script">
			<xsl:call-template name="include-javascript"><xsl:with-param name="file" select="."/></xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="$page-meta/ws:script">
			<xsl:call-template name="include-javascript"><xsl:with-param name="file" select="."/></xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="$page-data/ws:script">
			<xsl:call-template name="include-javascript"><xsl:with-param name="file" select="."/></xsl:call-template>
		</xsl:for-each>
	</xsl:template>


	<!-- Image pre-loader
	   -
	   - This template generates the code for the image pre-loader hidden div.
	  -->
	<xsl:template name="image-preloader">
		<xsl:if test="$d/ws:image-preload or $c-block/ws:image-preload or $page-meta/ws:image-preload or $page-data/ws:image-preload">
			<div style="display:none">
				<xsl:for-each select="$d/ws:image-preload">
					<img id="{@id}" alt="(preload)">
						<xsl:attribute name="src">
							<xsl:call-template name="image-source">
								<xsl:with-param name="file" select="@file" />
							</xsl:call-template>
						</xsl:attribute>
					</img>
				</xsl:for-each>
				<xsl:for-each select="$c-block/ws:image-preload">
					<img id="{@id}" alt="(preload)">
						<xsl:attribute name="src">
							<xsl:call-template name="image-source">
								<xsl:with-param name="file" select="@file" />
							</xsl:call-template>
						</xsl:attribute>
					</img>
				</xsl:for-each>
				<xsl:for-each select="$page-meta/ws:image-preload">
					<img id="{@id}" alt="(preload)">
						<xsl:attribute name="src">
							<xsl:call-template name="image-source">
								<xsl:with-param name="file" select="@file" />
							</xsl:call-template>
						</xsl:attribute>
					</img>
				</xsl:for-each>
				<xsl:for-each select="$page-data/ws:image-preload">
					<img id="{@id}" alt="(preload)">
						<xsl:attribute name="src">
							<xsl:call-template name="image-source">
								<xsl:with-param name="file" select="@file" />
							</xsl:call-template>
						</xsl:attribute>
					</img>
				</xsl:for-each>
			</div>
		</xsl:if>
	</xsl:template>


</xsl:stylesheet>