<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">

	<xsl:output method="xml"
			omit-xml-declaration="no"
			indent="yes"
			media-type="application/xhtml+xml"
			doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"
			doctype-public="-//W3C//DTD XHTML 1.1//EN" />


	<!-- Import libraries -->
	<xsl:include href="lib/utils.xsl" />
	<xsl:include href="lib/html-header.xsl" />
	<xsl:include href="lib/side-bar.xsl" />
	<xsl:include href="lib/breadcrumb.xsl" />
	<xsl:include href="lib/menu.xsl" />
	<xsl:include href="lib/history.xsl" />
	<xsl:include href="lib/rss-feeds.xsl" />
	<xsl:include href="lib/data.xsl" />


	<!-- Import layout styles -->
	<xsl:include href="templates/page-title.xsl" />
	<xsl:include href="templates/body.xsl" />
	<xsl:include href="templates/side-bar.xsl" />
	<xsl:include href="templates/side-box.xsl" />
	<xsl:include href="templates/language-selector.xsl" />
	<xsl:include href="templates/menu-item.xsl" />
	<xsl:include href="templates/short-history-entry.xsl" />
	<xsl:include href="templates/complete-history-entry.xsl" />


	<!-- *********************************************************************************************** -->
	<!-- * PARAMETERS                                                                                  * -->
	<!-- *********************************************************************************************** -->

	<!-- Requested page (defaulting to 'main') -->
	<xsl:param name="reqPage">main</xsl:param>

	<!-- Requested language (defaulting to 'en') -->
	<xsl:param name="reqLang">en</xsl:param>

	<!-- Path to the web root -->
	<xsl:param name="webRoot" />

	<!-- Path to the page generator script -->
	<xsl:param name="scriptPath" />




	<!-- *********************************************************************************************** -->
	<!-- * VARIABLES                                                                                   * -->
	<!-- *********************************************************************************************** -->


	<!-- Root of the data file -->
	<xsl:variable name="d" select="/ws:data" />


	<!-- Actual page to display -->
	<xsl:variable name="page">
		<xsl:choose>

			<!-- If the page exists in the site map, that's the one -->
			<xsl:when test="$d/ws:sitemap/ws:page[@id = $reqPage]">
				<xsl:value-of select="$reqPage" />
			</xsl:when>

			<!-- If a main page has been specified, use it -->
			<xsl:when test="$d/ws:sitemap/@home">
				<xsl:value-of select="$d/ws:sitemap/@home" />
			</xsl:when>

			<!-- Otherwise use the default "main" page name -->
			<xsl:otherwise>main</xsl:otherwise>

		</xsl:choose>
	</xsl:variable>


	<!-- Actual language to use -->
	<xsl:variable name="lang">
		<xsl:choose>

			<!-- Does the page exist in the requested language? -->
			<xsl:when test="$d/ws:contents[@lang = $reqLang]/ws:pages/ws:page[@id = $page]">
				<xsl:value-of select="$reqLang" />
			</xsl:when>

			<!-- No, attempt to find a language in which it exists -->
			<xsl:when test="$d/ws:contents/ws:pages/ws:page[@id = $reqPage]">
				<xsl:value-of select="$d/ws:contents/ws:pages/ws:page[@id = $reqPage and position() = 1]/../../@lang" />
			</xsl:when>

			<!-- Fall back to English ... but we're screwed anyway. -->
			<xsl:otherwise>en</xsl:otherwise>

		</xsl:choose>
	</xsl:variable>


	<!-- Root of the contents block -->
	<xsl:variable name="c-block" select="$d/ws:contents[@lang = $lang]" />


	<!-- Sitemap entry of the page -->
	<xsl:variable name="page-meta" select="$d/ws:sitemap/ws:page[@id = $page]" />


	<!-- Contents entry of the page -->
	<xsl:variable name="page-data" select="$c-block/ws:pages/ws:page[@id = $page]" />


	<!-- Page author, if there is one. If there is no page-specific author, use the site-wise value.
	   - If there is no site-wise author, don't send any author metadata.
	   -->
	<xsl:variable name="page-author">
		<xsl:choose>

			<!-- Use the page-specific author if it has been specified -->
			<xsl:when test="$page-meta/@author">
				<xsl:value-of select="$page-meta/@author" />
			</xsl:when>

			<!-- Fallback to the site-wise author -->
			<xsl:when test="$d/ws:author">
				<xsl:value-of select="$d/ws:author" />
			</xsl:when>

			<!-- No page author :'( -->
			<xsl:otherwise>
				<xsl:value-of select="false" />
			</xsl:otherwise>

		</xsl:choose>
	</xsl:variable>


	<!-- *********************************************************************************************** -->
	<!-- * DOCUMENT GENERATOR                                                                          * -->
	<!-- *********************************************************************************************** -->

	<!-- Top-level
	   -
	   - This template, matching the root element of the main data file, generates the proper HTML
	   - tag and calls appropriate templates that will generate the header and body respectively.
	  -->
	<xsl:template match="/">
		<html>
			<xsl:attribute name="xml:lang">
				<xsl:value-of select="$lang" />
			</xsl:attribute>
			<head>
				<xsl:call-template name="html-header" />
			</head>
			<body>
				<xsl:call-template name="image-preloader" />
				<xsl:call-template name="body-template">
					<xsl:with-param name="side-bar">
						<xsl:call-template name="generate-side-bar" />
					</xsl:with-param>
					<xsl:with-param name="contents">
						<xsl:for-each select="wsf:get-page-data( string( $page ) , string( $lang ) )">
							<xsl:apply-templates />
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</body>
		</html>
	</xsl:template>


</xsl:stylesheet>
